pub struct NuGetLockParser;Trait Implementations
Sourceimpl LockFileProvider for NuGetLockParser
impl LockFileProvider for NuGetLockParser
Sourcefn locate_lockfile(&self, manifest_uri: &Uri) -> Option<PathBuf>
fn locate_lockfile(&self, manifest_uri: &Uri) -> Option<PathBuf>
Locates the lock file for a given manifest URI. Read more
Sourcefn parse_lockfile<'a>(
&'a self,
lockfile_path: &'a Path,
) -> Pin<Box<dyn Future<Output = Result<ResolvedPackages>> + Send + 'a>>
fn parse_lockfile<'a>( &'a self, lockfile_path: &'a Path, ) -> Pin<Box<dyn Future<Output = Result<ResolvedPackages>> + Send + 'a>>
Parses a lock file and extracts resolved packages. Read more
Sourcefn is_lockfile_stale(
&self,
lockfile_path: &Path,
last_modified: SystemTime,
) -> bool
fn is_lockfile_stale( &self, lockfile_path: &Path, last_modified: SystemTime, ) -> bool
Checks if lock file has been modified since last parse. Read more